View report

# Van Duyn en van Arkel Garages

## Download and print your report

Save the report on your pc and print it. You can also modify it or add more information. Please note that changes made on your pc will not be saved in the OiRA tool

Use the report to:

- Provide evidence for supervisory authorities.
- Pass information to the people concerned (workers, safety reps, employer, OSH experts, ...)
- Monitor and assess whether necessary measures have been introduced.
- Record any revision if circumstances change (new machines, new workers, as a result of findings of any accident investigations, etc.)

Download the full report

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

### Use it to:

- Provide evidence for supervisory authorities (labour inspectorate).

We recommend to always keep an updated printed version of your risk assessment (report) available in your company!

Download the action plan

- Format: Office Open XML Workbook (.xlsx)
- Contains: only the measures to be implemented to effectively manage the identified risks.

### Use it to:

- Manage the problems/risks in your workplace (specific tasks, expertise, responsibilities, deadlines).

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | About